# Activations

SwiGLU (Swish-Gated Linear Unit) activation kernels used in LLaMA, PaLM, and other modern LLMs.

## Functions

::: rotalabs_accel.kernels.activations.swiglu_fused

::: rotalabs_accel.kernels.activations.swiglu_torch

## Classes

::: rotalabs_accel.kernels.activations.SwiGLU
